#
# spec file for package gnucash-docs
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnucash-docs
Version:        4.13
Release:        bp156.10.1
Summary:        Documentation Module for GnuCash
License:        GFDL-1.1-only AND GPL-2.0-or-later
Group:          Productivity/Office/Finance
URL:            https://www.gnucash.org/
Source:         https://sourceforge.net/projects/gnucash/files/gnucash%20(stable)/%{version}/gnucash-docs-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  sgml-skel
BuildRequires:  xsltproc
BuildArch:      noarch
Recommends:     %{_bindir}/gnome-help

%description
GnuCash is a personal finance manager. A check-book like register GUI
allows you to enter and track bank accounts, stocks, income and even
currency trades. The interface is designed to be simple and easy to
use, but is backed with double-entry accounting principles to ensure
balanced books. This is the documentation module for GnuCash.

%prep
%setup -q

%build
%cmake
%cmake_build

%install
%cmake_install
%find_lang gnucash-guide %{?no_lang_C}
%find_lang gnucash-help %{?no_lang_C}
%{__rm} -rf %{buildroot}%{_datadir}/gnucash-docs
%fdupes %{buildroot}%{_datadir}

%files -f gnucash-guide.lang -f gnucash-help.lang
%license COPYING
%doc AUTHORS COPYING-DOCS NEWS README
%doc %{_datadir}/help/C/gnucash-guide
%doc %{_datadir}/help/C/gnucash-help

%changelog
* Thu Dec 22 2022 Dirk Müller <dmueller@suse.com>
- update to 4.13:
  * Bug 798620 - Unable to build docs on Mageia Cauldron
  * Bug 798623 - ENG. Typo "documenation"
  * Bug 798624 - Document how to check if GnuCash is running when
    updating quotes
  * Bug 798645 - screens instead of WINDOWS
  * Bug 798665 - New: ENG. Typo: Unnecessary determiner "a"
    in 2.6.1. Migrating financial data.
  * Bug 798674 - Broken link on Chapter 17. Python Bindings
  * Manual:de: Account_Actions: Tippfehler-Korrektur
  * Review URLs and replace them by entities in all parts and languages excepting in comments or FDL appendix
  * manual, ch_Finance-Quote: fix broken entities
  * gnc-gui-struct.dtd: fix some mistakes and add entities for menuitems and menuchoice.
  * Update url-irc to "irc://irc.gimp.net/gnucash" see the email announcement
  * Partial Modernization of Manual:C:Business: Differentiation of admonitions and improvement of lists
  * Manual:C: Convert CSV assistant into <procedure>
  * Multi-split csv elaboration
  * Update app-fq-vers to "1.53"
  * Replace "Online Quote Setup" instructions in Guide by links to the manual chapter.
    O Enhance bookinfos by subtitle and titleabbrev;drop "Help" from manual. Adding titleabbrev allows yelp to display the version in its titlebar
  * Guide:C: Fix image declarations: Some were not properly scaled and others didn't appear in the List of Figures.
  * Replace all hardcoded width="510[px]" by "&img-w;" for for both components in all languages
  * Ensure our documentation is also found when gnucash is run in KDE
  * Restore draft status in gnc-docbook.dtd.
  * New and Updated Translations: German
* Sat Oct  1 2022 Johannes Engel <jcnengel@gmail.com>
- Update to 4.12
* Fri Apr  1 2022 Johannes Engel <jcnengel@gmail.com>
- Update to 4.10.1
* Mon Jan  3 2022 Johannes Engel <jcnengel@gmail.com>
- Update to 4.9
  + Switch from autotools to cmake
  + See NEWS for details
* Mon Jul 12 2021 Johannes Engel <jcnengel@gmail.com>
- Update to 4.6
  + See NEWS for details
* Fri Apr  9 2021 Frank H. Ellenberger <frank.h.ellenberger@gmail.com>
- Update to 4.5
  + See NEWS for details
  + Set Release according rpmlint
* Sun May 31 2020 Frank H. Ellenberger <frank.h.ellenberger@gmail.com>
- Update to 3.10
  + Download URL changed
  + For changes of the packet see https://www.gnucash.org/news.phtml
* Sun Dec 23 2018 rpm@fthiessen.de
- Update to 3.3:
  + Add Reconciliation definition to glossary (bgo#791169)
  + None of the "GnuCash Tutorial and Concepts Guide" graphics
    display (bgo#796800)
  + Add information to Guide about file formats, esp. SQL.
    (bgo#777893)
  + Add tax tables to documentation.
  + Document Filter/Closing transactions feature.
- Recommend gnome-help, so GnuCash is able to retrieve and open
  guide files (boo#1099804)
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.2:
  + Missing images in Tutorial and Concepts Guide in PDF and Online
    Help pages (bgo#796098).
  + Void Reason Has No Visible Purpose (bgo#795980).
- Changes from version 3.1:
  + Update supported platforms for version 3.x.
* Fri Apr  6 2018 bjorn.lie@gmail.com
- Update to version 3.0:
  + Correct field format in python-import-fields.
  + Clarify that creating a postponed SX will use the original
    date.
  + Remove 'Remainder To' from loan assistant page 2.
  + Update partial date entry documentation based on new default
    behaviour.
  + Fix chm mapfile target and cleanfiles. The mapfile target would
    fail if the directory was already built, apparently not
    recognizing that its target was complete.
  + Cleanfiles was missing several build targets.
  + New Transaction Report section in Guide.
  + Replace some screenshots with new ones reflecting Gtk3.
  + Bugs fixed: bgo#122895, bgo#634181, bgo#608098, bgo#760407,
    bgo#762088.
  + Updated translations.
- Changes from version 2.6.20:
  + Link the referenced 'Simple Transaction Example' in
    Transactions 'Opening Balances'.
  + Add a link from '8.5.1. Loan Specifications' to '8.3.
    Calculations' SX:XRO.
  + Add Preference Online Quotes.
  + Bugs fixed: bgo#793844, bgo#770132, bgo#770132, bgo#792756.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Dec 21 2017 luc14n0@linuxmail.org
- Update to version 2.6.19:
  + Help 10.2. Setting Preferences is outdated #105 (bgo#782423).
  + Changing text in Help to reflect changes in Preferences
    dialogs.
  + Updated translations.
* Sun Nov  5 2017 badshah400@gmail.com
- Update to version 2.6.18:
  + The Italian Help translation, which uniquely uses a PO file,
    is frozen at commit 78cfa76 because of lack of a translator to
    maintain it.
  + Begin a Russian translation of the Guide by Dimitry Mangul.
  + Some spelling corrections in the German Guide.
  + Bugs fixed: bgo#120940.
- Change Source url to one that works correctly with source
  services: the previous url was downloading a tarball called
  "download"; in addition, the new url is also less clumsy
  looking.
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 2.6.17:
  + Improve internationalization of the Tutorial and Concepts
    Guide.
  + Bugs fixed: bgo#781711, bgo#781714.
- Fix source url.
* Wed Mar 29 2017 sfalken@opensuse.org
- Update to version 2.6.16:
  + Remove section "Changing the Register View" as better handled
    in Guide section 4.2.
  + Glossary: Transactions have at least 2 splits.
  + Bugs Fixed: bgo#755174, bgo#769457, bgo#774658, bgo#777318
    bgo#777287.
* Fri Feb 24 2017 zaitor@opensuse.org
- Fixup sourceurl and add proper tarball, the previous sub had the
  tarball named download.
* Fri Jan 20 2017 zaitor@opensuse.org
- Update to version 2.6.15:
  + Fix resolution of screenshots.
  + Bugs fixed: bgo#397135, bgo#633590, bgo#743671, bgo#755174,
    bgo#770371, bgo#775592, bgo#775919.
  + Updated translations.
- Drop rarian-scrollkeeper-compat BuildRequires: No longer strictly
  needed.
- Drop libgnome BuildRequires: Previously added just for for dir
  ownership. In stead just plainly own dirs in filelist.
* Thu Nov  3 2016 dimstar@opensuse.org
- Update to version 2.6.14:
  + Update the list of Finance::Quote methods to 1.38.
  + Bugs fixed: bgo#115461, bgo#687290, bgo#769457, bgo#769746,
    bgo#771230, bgo#769663.
  + Updated translations.
- Changes from version 2.6.13:
  + Fix unclear statement re docbook stylesheets in README.
  + Fix the very stale Release Schedule link in the Guide.
  + Bugs fixed: bgo#637004, bgo#712764, bgo#751686, bgo#754239,
    bgo#754239, bgo#765131.
* Mon Jun 27 2016 zaitor@opensuse.org
- Update to version 2.6.12:
  + Update instructions for updating quote prices by cron.
  + Add links to where common report preferences are set.
  + Setting number format details appear wrong in Help, section
    10.3.4. Counters Book Options Tab.
  + Update documentation for Invoice and Bill payments to reflect
    the new features.
  + Add missing sect Guide ch2.8: New book options in New Acct
    Hierarchy.
  + Remove Section 9.4.3 From Guide that offered simplistic advice
    about money and life that does nothing to explain GnuCash
    functionality or use.
  + Add note to Guide section 2.3.3 For Column Widths.
  + Updated translations.
* Tue Jan 12 2016 dimstar@opensuse.org
- Update to version 2.6.11:
  + Kep documentation in sync for latest release.
* Wed Jul  8 2015 zaitor@opensuse.org
- Update to version 2.6.7:
  + Fix typo.
  + Verbessere Erklärung Soll & Haben.
  + Add source link and translator comment to
    Help_txf-categories.xml.
* Tue Apr  7 2015 zaitor@opensuse.org
- Update to version 2.6.6:
  + Explain sorting by TXF code within Tax Form Sections.
  + Insert Part designations and update the Basics Chapter.
  + Document latest changes to the Advanced Portfolio Report.
  + Remove obolete sections about "Cannot find default values" left
    over from gconf.
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 2.6.5:
  + Fix a path of freshly added XML files.
  + Add some comments about translation to the German documents
    where the translation wasn't updated to match the English
    version.
  + Apply &untranslated property in German translations.
  + Fix bgo#739380: Release tarball build fails. Git builds OK.
* Tue Sep 30 2014 dimstar@opensuse.org
- Update to version 2.6.4:
  + Add sentence about manually editing payment information for
    customers.
  + Add warning and tip about account separator character.
  + Correct field format in python-import-fields.
  + Currency movements .. remain fully balanced if "Trading
    Accounts" is enabled; "double entry" was not sufficient.
  + Improve explanation that Credit does NOT decrease equity
    accounts.
  + Improve readability of "Credit does NOT decrease ...".
  + New chapters in the German translation: Overview, Basics, and
    Accounts.
  + Reduced proportional width of description column to increase
    overall font size for a 510 pixel width image.
  + Remove a few discrepancies between the german guide overview
    and other components.
  + Update of translators in gnucash-guide-de.omf
  + Updated documentation to explain how to tie dividends received
    in cash to the appropriate stock holding.
  + Updated translations.
* Sat Apr  5 2014 zaitor@opensuse.org
- Update to version 2.6.3:
  + There have been no documentation changes since 2.6.2.
* Fri Mar 14 2014 zaitor@opensuse.org
- Update to version 2.6.2:
  + Help text for Employee section missing (bgo#547386).
  + One error and some typos in documentation (bgo#723173).
  + Dividends reinvested example text doesn't match graphic. Also
    remove a useless figure and improve text (bgo#725013).
  + Assorted typos and version number corrections.
* Tue Feb  4 2014 ro@suse.de
- Drop kdelibs3-doc BuildRequires: no longer needed.
* Sun Feb  2 2014 dimstar@opensuse.org
- Update to version 2.6.1:
  + First documention updates for credit notes.
  + Adapt migration documentation to gsettings introduction.
  + Move most of the text regarding business features from guide to
    help, correct links and wording and many small improvements.
  + Add information about the Business tab in book options window.
  + Enable building Japanese PDF without requiring Debian or
    downloading fonts from anywhere.
  + Add Fedora font paths.
  + Adjust image after update.
  + Doc/guide/C: add cash account to accts-examples-organization2.
  + Docs/guide/de: minor corrections of spelling.
  + Updated translations.
* Wed Jan 22 2014 dimstar@opensuse.org
- Update to version 2.6.0:
  + Updated documentation for new GnuCash stable version 2.6.0:
  - Update Preferences section.
  - Menu and Toolbar references.
  - Update Business Documentation: Bobby Ratliff.
  - Budget Features: Bobby Ratliff.
  + Update Copyrights, Author lists, and metadata.
  + Add facility to publish docs as e-pubs.
  + Bugs fixed: bgo#513122, bgo#604519, bgo#608932, bgo#633524,
    bgo#638955, bgo#639264, bgo#661705, bgo#670354, bgo#672668,
    bgo#684709, bgo#687476, bgo#688425, bgo#688579, bgo#688968,
    bgo#691762, bgo#692917, bgo#693493, bgo#699430, bgo#700656,
    bgo#702039, bgo#712308:, bgo#715161.
  + Updated translations.
* Wed Dec 11 2013 dimstar@opensuse.org
- Replace scrollkeeper BuildRequires with xsltproc and
  rarian-scrollkeeper-compat: scrollkeeper has been replaced by
  rarian. Scrollkeeper also pulled in xsltproc, but that was not
  an entirely correct requirement.
* Tue Nov 20 2012 dimstar@opensuse.org
- Update to version 2.4.2:
  + New or improved documentation for "Data migration".
  + New documentation formats: epub and mobi.
  + Several small updates and fixes.
  + Updated translations.
- Drop gnucash-docs-fixup.patch: fixed upstream.
- Drop libtool BuildRequires and call to autogen.sh, as we are
  able to use the upstream tarball again.
* Fri Jul 20 2012 dimstar@opensuse.org
- Add a self created source tarball, directly exported from svn.
  The upstream provided tarball misses a bunch of file (notably in
  the german language), which are all in svn, but due them not
  being listed in Makefile.am, make dist did not add them to the
  tarball (Addresses part of bnc#771530).
- Add gnucash-docs-fixup.patch: mark the missing files to be
  installed as well.
- Add libtool BuildRequires and call autogen.sh in build section,
  as this tarball has not been preprocessed at all.
* Mon Sep 26 2011 andrea.turrini@gmail.com
- Fix typo in description.
* Thu Aug  4 2011 dimstar@opensuse.org
- Update to version 2.4.1:
  + Allow control over scrollkeeper omf file installation using
  - -disable-scrollkeeper as configure parameter.
  + Other buildsystem fixes.
- Clean spec-file using spec-cleaner.
- Use grep -E instead of egrep to fix a rpmlint warning.
* Fri Jul 27 2007 sbrabec@suse.cz
- Updated to version 2.2.0:
  * Documents gnucash 2.2.0.
* Wed Mar  7 2007 jhargadon@suse.de
- removed Requires: yelp (#250500)
* Fri Feb 16 2007 sbrabec@suse.cz
- New SuSE package, version 2.0.1 (#231168),
